<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca_ES">
<context>
    <name>GPIOConfiguration</name>
    <message>
        <location filename="gpioconfiguration.ui" line="33"/>
        <source>Configure GPIO Plugin</source>
        <translation>Configurar el plugin GPIO</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.ui" line="46"/>
        <source>Selected chip</source>
        <translation>Xip seleccionat</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.ui" line="57"/>
        <source>GPIO Number</source>
        <translation>Nombre GPIO</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.ui" line="62"/>
        <source>Usage</source>
        <translation>Ús</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.ui" line="67"/>
        <source>Channel number</source>
        <translation>Número de canal</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.cpp" line="79"/>
        <source>Not used</source>
        <translation>No usat</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.cpp" line="80"/>
        <source>Input</source>
        <translation>Entrada</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.cpp" line="81"/>
        <source>Output</source>
        <translation>Sortida</translation>
    </message>
</context>
<context>
    <name>GPIOPlugin</name>
    <message>
        <location filename="gpioplugin.cpp" line="97"/>
        <source>This plugin provides input/output on GPIO PINs.</source>
        <translation>Aquest plugin proveeix entrada/sortida a GPIO PINs.</translation>
    </message>
</context>
</TS>
